@@ -1,11 +1,11 @@
 #ifndef NEWSBOAT_COLORMANAGER_H_
 #define NEWSBOAT_COLORMANAGER_H_
 
+#include <functional>
 #include <map>
 #include <vector>
 
 #include "configactionhandler.h"
-#include "stflpp.h"
 
 namespace podboat {
 class PbView;
@@ -31,7 +31,8 @@ public:
 	void handle_action(const std::string& action,
 		const std::vector<std::string>& params) override;
 	void dump_config(std::vector<std::string>& config_output) const override;
-	void apply_colors(Stfl::Form& form) const;
+	void apply_colors(std::function<void(const std::string&, const std::string&)>
+		stfl_value_setter) const;
 	std::map<std::string, TextStyle> get_styles() const
 	{
 		return element_styles;
