@@ -48,18 +48,15 @@ std::string consolidate_whitespace(const std::string& str);
 
 std::string translit(const std::string& tocode,
 	const std::string& fromcode);
-std::string convert_text(const std::string& text,
-	const std::string& tocode,
-	const std::string& fromcode);
 
 /// Converts input string from UTF-8 to the locale's encoding (as detected by
 /// nl_langinfo(CODESET)).
 std::string utf8_to_locale(const std::string& text);
+/// Converts input string from the locale's encoding (as detected by
+/// nl_langinfo(CODESET)) to UTF-8.
+std::string locale_to_utf8(const std::string& text);
 
 std::string get_command_output(const std::string& cmd);
-void extract_filter(const std::string& line,
-	std::string& filter,
-	std::string& url);
 std::string http_method_str(const HTTPMethod method);
 std::string retrieve_url(const std::string& url,
 	ConfigContainer* cfgcont = nullptr,
@@ -67,8 +64,6 @@ std::string retrieve_url(const std::string& url,
 	const std::string* body = nullptr,
 	const HTTPMethod method = HTTPMethod::GET,
 	CURL* easyhandle = nullptr);
-void run_command(const std::string& cmd,
-	const std::string& param); // used for notifications only
 std::string run_program(const char* argv[], const std::string& input);
 
 std::string resolve_tilde(const std::string&);
@@ -89,9 +84,6 @@ std::string absolute_url(const std::string& url,
 
 std::string get_useragent(ConfigContainer* cfgcont);
 
-size_t strwidth(const std::string& s);
-size_t strwidth_stfl(const std::string& str);
-
 std::string substr_with_width(const std::string& str,
 	const size_t max_width);
 
@@ -101,9 +93,6 @@ std::string substr_with_width_stfl(const std::string& str,
 unsigned int to_u(const std::string& str,
 	const unsigned int default_value = 0);
 
-bool is_valid_color(const std::string& color);
-bool is_valid_attribute(const std::string& attrib);
-
 std::vector<std::pair<unsigned int, unsigned int>> partition_indexes(
 		unsigned int start,
 		unsigned int end,
@@ -127,13 +116,6 @@ std::string quote_if_necessary(const std::string& str);
 void set_common_curl_options(CURL* handle, ConfigContainer* cfg);
 
 curl_proxytype get_proxy_type(const std::string& type);
-unsigned long get_auth_method(const std::string& type);
-
-bool is_special_url(const std::string& url);
-bool is_http_url(const std::string& url);
-bool is_query_url(const std::string& url);
-bool is_filter_url(const std::string& url);
-bool is_exec_url(const std::string& url);
 
 std::string get_content(xmlNode* node);
 std::string get_basename(const std::string& url);
@@ -141,8 +123,6 @@ std::string get_basename(const std::string& url);
 std::string unescape_url(const std::string& url);
 void initialize_ssl_implementation(void);
 
-unsigned int gentabs(const std::string& str);
-
 int mkdir_parents(const std::string& pathname,
 	mode_t mode = 0755);
 
@@ -151,6 +131,9 @@ std::string make_title(const std::string& url);
 nonstd::optional<std::uint8_t> run_interactively(const std::string& command,
 	const std::string& caller);
 
+nonstd::optional<std::uint8_t> run_non_interactively(const std::string& command,
+	const std::string& caller);
+
 std::string getcwd();
 
 enum class ReadTextFileErrorKind {
@@ -161,14 +144,8 @@ struct ReadTextFileError {
 	ReadTextFileErrorKind kind;
 	std::string message;
 };
-// We define an alias for this to work around a bug in AStyle: the poor
-// formatter can't decide how to split the function declaration into multiple
-// lines, and re-formats it differently on each invocation.
-using ReadTextFileResult =
-	nonstd::expected<std::vector<std::string>, ReadTextFileError>;
-ReadTextFileResult read_text_file(const std::string& filename);
-
-int strnaturalcmp(const std::string& a, const std::string& b);
+nonstd::expected<std::vector<std::string>, ReadTextFileError> read_text_file(
+	const std::string& filename);
 
 void remove_soft_hyphens(std::string& text);
 
@@ -183,9 +160,6 @@ std::string get_default_browser();
 /// value from config.h if there is no Git directory.
 std::string program_version();
 
-/// Newsboat's major version number.
-unsigned int newsboat_version_major();
-
 /// Threadsafe combination of strftime() and localtime()
 std::string mt_strf_localtime(const std::string& format, time_t t);
 }
