@@ -145,7 +145,7 @@ void print_usage(const std::string& argv0, const std::string& config_path,
 	print_filepath(tr_cache, cache_path);
 
 	std::cout << std::endl
-		<< _("Support at #newsboat at https://freenode.net or on our mailing "
+		<< _("Support at #newsboat at https://libera.chat or on our mailing "
 			"list https://groups.google.com/g/newsboat")
 		<< std::endl
 		<< _("For more information, check out https://newsboat.org/")
@@ -256,22 +256,22 @@ int main(int argc, char* argv[])
 	try {
 		ret = c.run(args);
 	} catch (const newsboat::DbException& e) {
+		Stfl::reset();
 		std::cerr << strprintf::fmt(
-				_("Caught newsboat::DbException with "
-					"message: %s"),
+				_("Caught newsboat::DbException with message: %s"),
 				e.what())
 			<< std::endl;
 		::exit(EXIT_FAILURE);
 	} catch (const newsboat::MatcherException& e) {
+		Stfl::reset();
 		std::cerr << strprintf::fmt(
-				_("Caught newsboat::MatcherException with "
-					"message: %s"),
+				_("Caught newsboat::MatcherException with message: %s"),
 				e.what())
 			<< std::endl;
 		::exit(EXIT_FAILURE);
 	} catch (const newsboat::Exception& e) {
-		std::cerr << strprintf::fmt(_("Caught newsboat::Exception with "
-					"message: %s"),
+		Stfl::reset();
+		std::cerr << strprintf::fmt(_("Caught newsboat::Exception with message: %s"),
 				e.what())
 			<< std::endl;
 		::exit(EXIT_FAILURE);
