@@ -12,7 +12,9 @@ fn add_cxxbridge(module: &str) {
 fn main() {
     add_cxxbridge("cliargsparser");
     add_cxxbridge("fslock");
+    add_cxxbridge("history");
     add_cxxbridge("keymap");
+    add_cxxbridge("logger");
     add_cxxbridge("scopemeasure");
     add_cxxbridge("utils");
 }
