@@ -400,7 +400,7 @@ void Cache::populate_tables()
 		version.major,
 		version.minor);
 
-	if (version.major > utils::newsboat_version_major()) {
+	if (version.major > utils::newsboat_major_version()) {
 		const std::string msg =
 			"Database schema isn't supported because it's too new";
 		LOG(Level::ERROR, msg);
@@ -484,15 +484,6 @@ void Cache::mark_item_deleted(const std::string& guid, bool b)
 	run_sql_nothrow(query);
 }
 
-void Cache::mark_feed_items_deleted(const std::string& feedurl)
-{
-	std::lock_guard<std::mutex> lock(mtx);
-	std::string query = prepare_query(
-			"UPDATE rss_item SET deleted = 1 WHERE feedurl = '%s';",
-			feedurl);
-	run_sql_nothrow(query);
-}
-
 // this function writes an RssFeed including all RssItems to the database
 void Cache::externalize_rssfeed(std::shared_ptr<RssFeed> feed,
 	bool reset_unread)
@@ -574,8 +565,7 @@ std::shared_ptr<RssFeed> Cache::internalize_rssfeed(std::string rssurl,
 {
 	ScopeMeasure m1("Cache::internalize_rssfeed");
 
-	std::shared_ptr<RssFeed> feed(new RssFeed(this));
-	feed->set_rssurl(rssurl);
+	std::shared_ptr<RssFeed> feed(new RssFeed(this, rssurl));
 
 	if (utils::is_query_url(rssurl)) {
 		return feed;
@@ -747,9 +737,19 @@ void Cache::do_vacuum()
 	run_sql("VACUUM;");
 }
 
-void Cache::cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds,
+std::uint64_t Cache::cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds,
 	bool always_clean)
 {
+	std::uint64_t unreachable = 0u;
+	std::string list = "(";
+
+	for (const auto& feed : feeds) {
+		const auto name = prepare_query("'%q'", feed->rssurl());
+		list.append(name);
+		list.append(", ");
+	}
+	list.append("'')");
+
 	// we don't use the std::lock_guard<> here... see comments below
 	mtx.lock();
 
@@ -767,15 +767,6 @@ void Cache::cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds,
 	 */
 	if (always_clean || cfg->get_configvalue_as_bool("cleanup-on-quit")) {
 		LOG(Level::DEBUG, "Cache::cleanup_cache: cleaning up cache...");
-		std::string list = "(";
-
-		for (const auto& feed : feeds) {
-			std::string name =
-				prepare_query("'%q'", feed->rssurl());
-			list.append(name);
-			list.append(", ");
-		}
-		list.append("'')");
 
 		std::string cleanup_rss_feeds_statement(
 			"DELETE FROM rss_feed WHERE rssurl NOT IN ");
@@ -796,14 +787,31 @@ void Cache::cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds,
 				"delete-read-articles-on-quit")) {
 			run_sql(cleanup_read_items_statement);
 		}
-
-		// WARNING: THE MISSING UNLOCK OPERATION IS MISSING FOR A
-		// PURPOSE! It's missing so that no database operation can occur
-		// after the cache cleanup! mtx->unlock();
 	} else {
 		LOG(Level::DEBUG,
 			"Cache::cleanup_cache: NOT cleaning up cache...");
+
+		std::string query = (
+				"SELECT count(rss) "
+				"FROM ("
+				"SELECT feedurl AS rss FROM rss_item "
+				"UNION ALL "
+				"SELECT rssurl FROM rss_feed"
+				") "
+				"WHERE rss NOT IN "
+			);
+		query.append(list);
+		query.push_back(';');
+
+		CbHandler count_cbh;
+		run_sql(query, count_callback, &count_cbh);
+		unreachable = count_cbh.count();
 	}
+
+	// WARNING: THE MISSING UNLOCK OPERATION IS MISSING FOR A
+	// PURPOSE! It's missing so that no database operation can occur
+	// after the cache cleanup! mtx->unlock();
+	return unreachable;
 }
 
 void Cache::update_rssitem_unlocked(std::shared_ptr<RssItem> item,
