@@ -84,6 +84,18 @@ ConfigContainer::ConfigContainer()
 	{
 		"feedhq-url",
 		ConfigData("https://feedhq.org/", ConfigDataType::STR)},
+	{"freshrss-flag-star", ConfigData("", ConfigDataType::STR)},
+	{"freshrss-login", ConfigData("", ConfigDataType::STR)},
+	{"freshrss-min-items", ConfigData("20", ConfigDataType::INT)},
+	{"freshrss-password", ConfigData("", ConfigDataType::STR)},
+	{"freshrss-passwordfile", ConfigData("", ConfigDataType::PATH)},
+	{"freshrss-passwordeval", ConfigData("", ConfigDataType::STR)},
+	{
+		"freshrss-show-special-feeds",
+		ConfigData("true", ConfigDataType::BOOL)},
+	{
+		"freshrss-url",
+		ConfigData("", ConfigDataType::STR)},
 	{
 		"feedlist-format",
 		ConfigData("%4i %n %11u %t", ConfigDataType::STR)},
@@ -144,7 +156,7 @@ ConfigContainer::ConfigContainer()
 	{"notify-beep", ConfigData("no", ConfigDataType::BOOL)},
 	{
 		"notify-format",
-		ConfigData(_("newsboat: finished reload, %f unread "
+		ConfigData(_("Newsboat: finished reload, %f unread "
 				"feeds (%n unread articles total)"),
 			ConfigDataType::STR)},
 	{"notify-program", ConfigData("", ConfigDataType::PATH)},
@@ -205,6 +217,7 @@ ConfigContainer::ConfigContainer()
 		ConfigData("false", ConfigDataType::BOOL)},
 	{"reload-threads", ConfigData("1", ConfigDataType::INT)},
 	{"reload-time", ConfigData("60", ConfigDataType::INT)},
+	{"restrict-filename", ConfigData("yes", ConfigDataType::BOOL)},
 	{"save-path", ConfigData("~/", ConfigDataType::PATH)},
 	{"scrolloff", ConfigData("0", ConfigDataType::INT)},
 	{
@@ -261,6 +274,7 @@ ConfigContainer::ConfigContainer()
 			"ttrss",
 			"newsblur",
 			"feedhq",
+			"freshrss",
 			"ocnews",
 			"miniflux",
 			"inoreader"}))},
@@ -270,18 +284,14 @@ ConfigContainer::ConfigContainer()
 	/* title formats: */
 	{
 		"articlelist-title-format",
-		ConfigData(_("%N %V - Articles in feed '%T' (%u unread, %t total)"
-				"%?F? matching filter `%F'&?"
-				" - %U"),
+		ConfigData(_("%N %V - Articles in feed '%T' (%u unread, %t total)%?F? matching filter '%F'&? - %U"),
 			ConfigDataType::STR)},
 	{
 		"dialogs-title-format",
 		ConfigData(_("%N %V - Dialogs"), ConfigDataType::STR)},
 	{
 		"feedlist-title-format",
-		ConfigData(_("%N %V - %?F?Feeds&Your feeds? (%u unread, %t total)"
-				"%?F? matching filter `%F'&?"
-				"%?T? - tag `%T'&?"),
+		ConfigData(_("%N %V - %?F?Feeds&Your feeds? (%u unread, %t total)%?F? matching filter '%F'&?%?T? - tag '%T'&?"),
 			ConfigDataType::STR)},
 	{
 		"filebrowser-title-format",
@@ -296,13 +306,11 @@ ConfigContainer::ConfigContainer()
 		ConfigData(_("%N %V - Help"), ConfigDataType::STR)},
 	{
 		"itemview-title-format",
-		ConfigData(_("%N %V - Article '%T' (%u unread, %t "
-				"total)"),
+		ConfigData(_("%N %V - Article '%T' (%u unread, %t total)"),
 			ConfigDataType::STR)},
 	{
 		"searchresult-title-format",
-		ConfigData(_("%N %V - Search results (%u unread, %t total)"
-				"%?F? matching filter `%F'&?"),
+		ConfigData(_("%N %V - Search results (%u unread, %t total)%?F? matching filter '%F'&?"),
 			ConfigDataType::STR)},
 	{
 		"selectfilter-title-format",
@@ -317,7 +325,8 @@ ConfigContainer::ConfigContainer()
 		ConfigData(_("%N %V - URLs"), ConfigDataType::STR)},
 	{
 		"wrap-scroll",
-		ConfigData("no", ConfigDataType::BOOL)}}
+		ConfigData("no", ConfigDataType::BOOL)},
+}
 {
 }
 
@@ -358,8 +367,10 @@ void ConfigContainer::handle_action(const std::string& action,
 		action,
 		static_cast<unsigned int>(cfgdata.type()));
 
-	if (params.size() < 1) {
+	if (params.size() == 0) {
 		throw ConfigHandlerException(ActionHandlerStatus::TOO_FEW_PARAMS);
+	} else if (params.size() > 1 && !cfgdata.multi_option()) {
+		throw ConfigHandlerException(ActionHandlerStatus::TOO_MANY_PARAMS);
 	}
 
 	switch (cfgdata.type()) {
