@@ -35,6 +35,8 @@
 #include "exception.h"
 #include "feedhqapi.h"
 #include "feedhqurlreader.h"
+#include "freshrssapi.h"
+#include "freshrssurlreader.h"
 #include "fileurlreader.h"
 #include "globals.h"
 #include "inoreaderapi.h"
@@ -83,7 +85,7 @@ Controller::Controller(ConfigPaths& configpaths)
 	, refresh_on_start(false)
 	, api(0)
 	, configpaths(configpaths)
-	, queueManager(&cfg, &configpaths)
+	, queueManager(&cfg, configpaths.queue_file())
 {
 }
 
@@ -171,9 +173,10 @@ int Controller::run(const CliArgsParser& args)
 	cfgparser.register_handler("define-filter", filters);
 	cfgparser.register_handler("highlight", rxman);
 	cfgparser.register_handler("highlight-article", rxman);
+	cfgparser.register_handler("highlight-feed", rxman);
 
 	try {
-		cfgparser.parse_file("/etc/" PROGRAM_NAME "/config");
+		cfgparser.parse_file("/etc/" PACKAGE "/config");
 		cfgparser.parse_file(configpaths.config_file());
 	} catch (const ConfigException& ex) {
 		LOG(Level::ERROR,
@@ -279,6 +282,30 @@ int Controller::run(const CliArgsParser& args)
 	} else if (type == "feedhq") {
 		api = new FeedHqApi(&cfg);
 		urlcfg = new FeedHqUrlReader(&cfg, configpaths.url_file(), api);
+	} else if (type == "freshrss") {
+		const auto freshrss_url = cfg.get_configvalue("freshrss-url");
+		if (freshrss_url.empty()) {
+			std::cerr <<
+				_("ERROR: You must set `freshrss-url` to use FreshRSS\n");
+			return EXIT_FAILURE;
+		}
+
+		const std::string user = cfg.get_configvalue("freshrss-login");
+		const std::string pass = cfg.get_configvalue("freshrss-password");
+		const std::string pass_file = cfg.get_configvalue("freshrss-passwordfile");
+		const std::string pass_eval = cfg.get_configvalue("freshrss-passwordeval");
+		const bool creds_set = !user.empty() &&
+			(!pass.empty() || !pass_file.empty() || !pass_eval.empty());
+		if (!creds_set) {
+			std::cerr <<
+				_("ERROR: You must set `freshrss-login` and one of `freshrss-password`, "
+					"`freshrss-passwordfile` or `freshrss-passwordeval` to use "
+					"FreshRSS\n");
+			return EXIT_FAILURE;
+		}
+
+		api = new FreshRssApi(&cfg);
+		urlcfg = new FreshRssUrlReader(&cfg, configpaths.url_file(), api);
 	} else if (type == "ocnews") {
 		api = new OcNewsApi(&cfg);
 		urlcfg = new OcNewsUrlReader(configpaths.url_file(), api);
