@@ -158,8 +158,7 @@ void HelpFormAction::prepare()
 
 		if (unbound_count > 0) {
 			listfmt.add_line("");
-			listfmt.add_line(
-				_("Unbound functions:"));
+			listfmt.add_line(_("Unbound functions:"));
 			listfmt.add_line("");
 
 			for (const auto& desc : descs) {
@@ -175,6 +174,24 @@ void HelpFormAction::prepare()
 			}
 		}
 
+		const auto macros = v->get_keymap()->get_macro_descriptions();
+		if (!macros.empty()) {
+			listfmt.add_line("");
+			listfmt.add_line(_("Macros:"));
+			listfmt.add_line("");
+
+			for (const auto& macro : macros) {
+				const std::string key = macro.first;
+				const std::string description = macro.second.description;
+
+				// "macro-prefix" is not translated because it refers to an operation name
+				std::string line = strprintf::fmt("<macro-prefix>%s  %s", key, description);
+				line = utils::quote_for_stfl(line);
+				line = apply_highlights(line);
+				listfmt.add_line(line);
+			}
+		}
+
 		textview.stfl_replace_lines(listfmt.get_lines_count(), listfmt.format_list());
 
 		do_redraw = false;
