@@ -231,7 +231,7 @@ void PbController::initialize(int argc, char* argv[])
 	};
 
 	std::cout << strprintf::fmt(
-			_("Starting %s %s..."), "podboat", utils::program_version())
+			_("Starting %s %s..."), "Podboat", utils::program_version())
 		<< std::endl;
 
 	fslock = std::unique_ptr<FsLock>(new FsLock());
@@ -244,7 +244,7 @@ void PbController::initialize(int argc, char* argv[])
 			std::cout << strprintf::fmt(
 					_("Error: an instance of %s is already "
 						"running (PID: %" PRId64 ")"),
-					"podboat",
+					"Podboat",
 					p)
 				<< std::endl;
 		} else {
@@ -270,6 +270,7 @@ void PbController::initialize(int argc, char* argv[])
 	cfgparser.register_handler("define-filter", null_cah);
 	cfgparser.register_handler("highlight", null_cah);
 	cfgparser.register_handler("highlight-article", null_cah);
+	cfgparser.register_handler("highlight-feed", null_cah);
 	cfgparser.register_handler("reset-unread-on-update", null_cah);
 	cfgparser.register_handler("run-on-startup", null_cah);
 
@@ -315,7 +316,7 @@ void PbController::print_usage(const char* argv0)
 {
 	auto msg = strprintf::fmt(
 			_("%s %s\nusage %s [-C <file>] [-q <file>] [-h]\n"),
-			"podboat",
+			"Podboat",
 			utils::program_version(),
 			argv0);
 	std::cout << msg;
@@ -371,7 +372,7 @@ void PbController::print_usage(const char* argv0)
 	}
 
 	std::cout << std::endl
-		<< _("Support at #newsboat at https://freenode.net or on our mailing "
+		<< _("Support at #newsboat at https://libera.chat or on our mailing "
 			"list https://groups.google.com/g/newsboat")
 		<< std::endl
 		<< _("For more information, check out https://newsboat.org/")
