@@ -3,7 +3,7 @@
 #include <cinttypes>
 #include <cstdio>
 #include <cstring>
-#include <curses.h>
+#include <ncurses.h>
 #include <iostream>
 #include <sstream>
 
@@ -102,6 +102,8 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 				i++;
 			}
 
+			downloads_list.stfl_replace_lines(listfmt);
+
 			// If there's no status message, we know there's no error to show
 			// Thus, it's safe to replace with the download's status
 			if (i >= 1 && dllist_form.get("msg").empty()) {
@@ -109,8 +111,6 @@ void PbView::run(bool auto_download, bool wrap_scroll)
 				dllist_form.set("msg", ctrl->downloads()[idx].status_msg());
 			}
 
-			downloads_list.stfl_replace_lines(listfmt);
-
 			ctrl->set_view_update_necessary(false);
 		}
 
