@@ -61,17 +61,13 @@ bool UrlViewFormAction::process_operation(Operation op,
 	case OP_OPENINBROWSER:
 	case OP_OPENBROWSER_AND_MARK:
 	case OP_OPEN: {
-		if (!links.empty()) {
-			const unsigned int pos = urls_list.get_position();
-			v->set_status(_("Starting browser..."));
-			const std::string feedurl = (feed != nullptr ?
-					feed->rssurl() :
-					"");
-			v->open_in_browser(links[pos].first, feedurl);
-			v->set_status("");
-		} else {
-			v->show_error(_("No links available!"));
-		}
+		const bool interactive = true;
+		open_current_position_in_browser(interactive);
+	}
+	break;
+	case OP_OPENINBROWSER_NONINTERACTIVE: {
+		const bool interactive = false;
+		open_current_position_in_browser(interactive);
 	}
 	break;
 	case OP_BOOKMARK: {
@@ -79,7 +75,7 @@ bool UrlViewFormAction::process_operation(Operation op,
 			const unsigned int pos = urls_list.get_position();
 			this->start_bookmark_qna("", links[pos].first, "", feed->title());
 		} else {
-			v->show_error(_("No links available!"));
+			v->get_statusline().show_error(_("No links available!"));
 		}
 	}
 	break;
@@ -96,12 +92,9 @@ bool UrlViewFormAction::process_operation(Operation op,
 		unsigned int idx = op - OP_OPEN_URL_1;
 
 		if (idx < links.size()) {
-			v->set_status(_("Starting browser..."));
-			const std::string feedurl = (feed != nullptr ?
-					feed->rssurl() :
-					"");
-			v->open_in_browser(links[idx].first, feedurl);
-			v->set_status("");
+			const std::string feedurl = (feed != nullptr ?  feed->rssurl() : "");
+			const bool interactive = true;
+			v->open_in_browser(links[idx].first, feedurl, interactive);
 		}
 	}
 	break;
@@ -127,6 +120,17 @@ bool UrlViewFormAction::process_operation(Operation op,
 	return true;
 }
 
+void UrlViewFormAction::open_current_position_in_browser(bool interactive)
+{
+	if (!links.empty()) {
+		const unsigned int pos = urls_list.get_position();
+		const std::string feedurl = (feed != nullptr ?  feed->rssurl() : "");
+		v->open_in_browser(links[pos].first, feedurl, interactive);
+	} else {
+		v->get_statusline().show_error(_("No links available!"));
+	}
+}
+
 void UrlViewFormAction::prepare()
 {
 	if (do_redraw) {
@@ -145,9 +149,7 @@ void UrlViewFormAction::prepare()
 
 void UrlViewFormAction::init()
 {
-	v->set_status("");
-
-	f.run(-3); // compute all widget dimensions
+	recalculate_widget_dimensions();
 
 	do_redraw = true;
 	quit = false;
@@ -162,7 +164,7 @@ void UrlViewFormAction::update_heading()
 	fmt.register_fmt('N', PROGRAM_NAME);
 	fmt.register_fmt('V', utils::program_version());
 
-	f.set("head",
+	set_value("head",
 		fmt.do_format(
 			cfg->get_configvalue("urlview-title-format"), width));
 }
@@ -183,7 +185,7 @@ void UrlViewFormAction::handle_cmdline(const std::string& cmd)
 	unsigned int idx = 0;
 	if (1 == sscanf(cmd.c_str(), "%u", &idx)) {
 		if (idx < 1 || idx > links.size()) {
-			v->show_error(_("Invalid position!"));
+			v->get_statusline().show_error(_("Invalid position!"));
 		} else {
 			urls_list.set_position(idx - 1);
 		}
