@@ -4,7 +4,6 @@
 #include <cerrno>
 #include <cstdio>
 #include <cstring>
-#include <curses.h>
 #include <dirent.h>
 #include <fstream>
 #include <grp.h>
@@ -210,7 +209,7 @@ int View::run()
 
 		if (have_macroprefix) {
 			have_macroprefix = false;
-			set_status("");
+			status_line.show_message("");
 			LOG(Level::DEBUG,
 				"View::run: running macro `%s'",
 				event);
@@ -225,7 +224,7 @@ int View::run()
 
 			if (OP_MACROPREFIX == op) {
 				have_macroprefix = true;
-				set_status("macro-");
+				status_line.show_message("macro-");
 			}
 
 			// now we handle the operation to the
@@ -290,17 +289,23 @@ std::string View::get_filename_suggestion(const std::string& s)
 {
 	/*
 	 * With this function, we generate normalized filenames for saving
-	 * articles to files.
+	 * articles to files if the setting `restrict-filename` is enabled.
 	 */
 	std::string retval;
-	for (unsigned int i = 0; i < s.length(); ++i) {
-		if (isalnum(s[i])) {
-			retval.push_back(s[i]);
-		} else if (s[i] == '/' || s[i] == ' ' || s[i] == '\r' ||
-			s[i] == '\n') {
-			retval.push_back('_');
+
+	if (cfg->get_configvalue_as_bool("restrict-filename")) {
+		for (unsigned int i = 0; i < s.length(); ++i) {
+			if (isalnum(s[i])) {
+				retval.push_back(s[i]);
+			} else if (s[i] == '/' || s[i] == ' ' || s[i] == '\r' ||
+				s[i] == '\n') {
+				retval.push_back('_');
+			}
 		}
+	} else {
+		retval = s;
 	}
+
 	if (retval.length() == 0) {
 		retval = "article.txt";
 	} else {
@@ -374,10 +379,9 @@ nonstd::optional<std::uint8_t> View::open_in_browser(const std::string& url,
 		pop_current_formaction();
 		return ret;
 	} else {
-		set_status(strprintf::fmt(_("Running browser: %s"), cmdline));
-		const auto ret = utils::run_non_interactively(cmdline, "View::open_in_browser");
-		set_status("");
-		return ret;
+		const std::shared_ptr<AutoDiscardMessage> message =
+			status_line.show_message_until_finished(strprintf::fmt(_("Running browser: %s"), cmdline));
+		return utils::run_non_interactively(cmdline, "View::open_in_browser");
 	}
 }
 
@@ -389,7 +393,7 @@ void View::update_visible_feeds(std::vector<std::shared_ptr<RssFeed>> feeds)
 			feedlist_form->update_visible_feeds(feeds);
 		}
 	} catch (const MatcherException& e) {
-		set_status(strprintf::fmt(
+		status_line.show_message(strprintf::fmt(
 				_("Error: applying the filter failed: %s"), e.what()));
 		LOG(Level::DEBUG,
 			"View::update_visible_feeds: inside catch: %s",
@@ -412,7 +416,7 @@ void View::set_feedlist(std::vector<std::shared_ptr<RssFeed>> feeds)
 			feedlist_form->set_feedlist(feeds);
 		}
 	} catch (const MatcherException& e) {
-		set_status(strprintf::fmt(
+		status_line.show_message(strprintf::fmt(
 				_("Error: applying the filter failed: %s"), e.what()));
 	}
 }
@@ -916,11 +920,11 @@ void View::prepare_query_feed(std::shared_ptr<RssFeed> feed)
 			"View::prepare_query_feed: %s",
 			feed->rssurl());
 
-		set_status(_("Updating query feed..."));
+		const std::shared_ptr<AutoDiscardMessage> message =
+			status_line.show_message_until_finished(_("Updating query feed..."));
 		feed->update_items(ctrl->get_feedcontainer()->get_all_feeds());
 		feed->sort(cfg->get_article_sort_strategy());
 		notify_itemlist_change(feed);
-		set_status("");
 	}
 }
 
@@ -966,11 +970,15 @@ void View::pop_current_formaction()
 			}
 			i++;
 		}
-		std::shared_ptr<FormAction> f = get_current_formaction();
-		if (f) {
-			f->set_redraw(true);
-			f->set_value("msg", "");
-			f->recalculate_widget_dimensions();
+
+		// Skip cleanup steps when returning from a transient EmptyFormAction
+		if (std::dynamic_pointer_cast<EmptyFormAction>(f) == nullptr) {
+			std::shared_ptr<FormAction> fa = get_current_formaction();
+			if (fa) {
+				fa->set_redraw(true);
+				fa->set_value("msg", "");
+				fa->recalculate_widget_dimensions();
+			}
 		}
 	}
 }
