@@ -4,6 +4,7 @@
 
 #include "confighandlerexception.h"
 #include "matchable.h"
+#include "matcherexception.h"
 
 using namespace newsboat;
 
@@ -226,8 +227,9 @@ TEST_CASE("quote_and_highlight wraps highlighted text in numbered tags",
 	}
 }
 
-TEST_CASE("RegexManager::dump_config turns each `highlight` and "
-	"`highlight-article` rule into a string, and appends them onto a vector",
+TEST_CASE("RegexManager::dump_config turns each `highlight`, "
+	"`highlight-article` and `highlight-feed` rule into a string, and appends "
+	"them onto a vector",
 	"[RegexManager]")
 {
 	RegexManager rxman;
@@ -255,6 +257,21 @@ TEST_CASE("RegexManager::dump_config turns each `highlight` and "
 		REQUIRE(result[0] == R"#(highlight "all" "keywords" "red" "blue")#");
 		REQUIRE(result[1] == R"#(highlight-article "title==\"\"" "green" "black")#");
 	}
+
+	SECTION("Three rules") {
+		rxman.handle_action("highlight", {"all", "keywords", "red", "blue"});
+		rxman.handle_action(
+			"highlight-article",
+		{"title==\"\"", "green", "black"});
+		rxman.handle_action(
+			"highlight-feed",
+		{"title==\"\"", "red", "black"});
+		REQUIRE_NOTHROW(rxman.dump_config(result));
+		REQUIRE(result.size() == 3);
+		REQUIRE(result[0] == R"#(highlight "all" "keywords" "red" "blue")#");
+		REQUIRE(result[1] == R"#(highlight-article "title==\"\"" "green" "black")#");
+		REQUIRE(result[2] == R"#(highlight-feed "title==\"\"" "red" "black")#");
+	}
 }
 
 TEST_CASE("RegexManager::dump_config appends to given vector", "[RegexManager]")
@@ -410,6 +427,55 @@ TEST_CASE("RegexManager doesn't throw on valid `highlight-article' definition",
 	REQUIRE_NOTHROW(rxman.handle_action("highlight-article", params));
 }
 
+TEST_CASE("RegexManager throws on invalid `highlight-feed' definition",
+	"[RegexManager]")
+{
+	RegexManager rxman;
+	std::vector<std::string> params;
+
+	SECTION("on `highlight-feed' without parameters") {
+		REQUIRE_THROWS_AS(rxman.handle_action("highlight-feed", params),
+			ConfigHandlerException);
+	}
+
+	SECTION("on invalid filter expression") {
+		params = {"a = b", "red", "green"};
+		REQUIRE_THROWS_AS(rxman.handle_action("highlight-feed", params),
+			ConfigHandlerException);
+	}
+
+	SECTION("on missing colors") {
+		params = {"title==\"\""};
+		REQUIRE_THROWS_AS(rxman.handle_action("highlight-feed", params),
+			ConfigHandlerException);
+	}
+
+	SECTION("on missing background color") {
+		params = {"title==\"\"", "white"};
+		REQUIRE_THROWS_AS(rxman.handle_action("highlight-feed", params),
+			ConfigHandlerException);
+	}
+}
+
+TEST_CASE("RegexManager doesn't throw on valid `highlight-feed' definition",
+	"[RegexManager]")
+{
+	RegexManager rxman;
+	std::vector<std::string> params;
+
+	params = {"title == \"\"", "blue", "red"};
+	REQUIRE_NOTHROW(rxman.handle_action("highlight-feed", params));
+
+	params = {"content =~ \"keyword\"", "blue", "red"};
+	REQUIRE_NOTHROW(rxman.handle_action("highlight-feed", params));
+
+	params = {"unread == \"yes\"", "blue", "red", "bold", "underline"};
+	REQUIRE_NOTHROW(rxman.handle_action("highlight-feed", params));
+
+	params = {"age > 3", "blue", "red", "bold", "underline"};
+	REQUIRE_NOTHROW(rxman.handle_action("highlight-feed", params));
+}
+
 struct RegexManagerMockMatchable : public Matchable {
 public:
 	nonstd::optional<std::string> attribute_value(const std::string& attribname)
@@ -475,6 +541,59 @@ TEST_CASE("RegexManager::article_matches returns -1 if there are no Matcher "
 	}
 }
 
+TEST_CASE("RegexManager::feed_matches returns position of the Matcher "
+	"that matches a given Matchable",
+	"[RegexManager]")
+{
+	RegexManager rxman;
+	RegexManagerMockMatchable mock;
+
+	const auto cmd = std::string("highlight-feed");
+
+	SECTION("Just one rule") {
+		rxman.handle_action(cmd, {"attr != \"hello\"", "red", "green"});
+
+		REQUIRE(rxman.feed_matches(&mock) == 0);
+	}
+
+	SECTION("Couple rules") {
+		rxman.handle_action(cmd, {"attr != \"val\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr # \"entry\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr == \"val\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr =~ \"hello\"", "green", "white"});
+
+		REQUIRE(rxman.feed_matches(&mock) == 2);
+	}
+}
+
+TEST_CASE("RegexManager::feed_matches returns -1 if there are no Matcher "
+	"to match a given Matchable",
+	"[RegexManager]")
+{
+	RegexManager rxman;
+	RegexManagerMockMatchable mock;
+
+	const auto cmd = std::string("highlight-feed");
+
+	SECTION("No rules") {
+		REQUIRE(rxman.feed_matches(&mock) == -1);
+	}
+
+	SECTION("Just one rule") {
+		rxman.handle_action(cmd, {"attr == \"hello\"", "red", "green"});
+
+		REQUIRE(rxman.feed_matches(&mock) == -1);
+	}
+
+	SECTION("Couple rules") {
+		rxman.handle_action(cmd, {"attr != \"val\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr # \"entry\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr =~ \"hello\"", "green", "white"});
+
+		REQUIRE(rxman.feed_matches(&mock) == -1);
+	}
+}
+
 TEST_CASE("RegexManager::remove_last_regex removes last added `highlight` rule",
 	"[RegexManager]")
 {
@@ -555,13 +674,22 @@ TEST_CASE("RegexManager uses POSIX extended regex syntax",
 	// ensure that we're using EREs, these tests try stuff that's *not*
 	// supported by EREs.
 	//
+	// FreeBSD 13 returns an error from regexec() instead of failing the match
+	// like other OSes do. That's why we wrap our tests in a try-catch.
+	//
 	// Ideas gleaned from https://www.regular-expressions.info/refcharacters.html
 
 	RegexManager rxman;
 
 	// Supported by Perl, PCRE, PHP and others
 	SECTION("No support for escape sequence") {
-		rxman.handle_action("highlight", {"articlelist", R"#(\Q*]+\E)#", "red"});
+		try {
+			rxman.handle_action("highlight", {"articlelist", R"#(\Q*]+\E)#", "red"});
+		} catch (const ConfigHandlerException& e) {
+			const std::string expected(
+				R"#(`\Q*]+\E' is not a valid regular expression: trailing backslash (\))#");
+			REQUIRE(e.what() == expected);
+		}
 
 		std::string input = "*]+";
 		rxman.quote_and_highlight(input, "articlelist");
@@ -569,7 +697,13 @@ TEST_CASE("RegexManager uses POSIX extended regex syntax",
 	}
 
 	SECTION("No support for hexadecimal escape") {
-		rxman.handle_action("highlight", {"articlelist", R"#(^va\x6Cue)#", "red"});
+		try {
+			rxman.handle_action("highlight", {"articlelist", R"#(^va\x6Cue)#", "red"});
+		} catch (const ConfigHandlerException& e) {
+			const std::string expected(
+				R"#(`^va\x6Cue' is not a valid regular expression: trailing backslash (\))#");
+			REQUIRE(e.what() == expected);
+		}
 
 		std::string input = "value";
 		rxman.quote_and_highlight(input, "articlelist");
@@ -577,7 +711,13 @@ TEST_CASE("RegexManager uses POSIX extended regex syntax",
 	}
 
 	SECTION("No support for \\a as alert/bell control character") {
-		rxman.handle_action("highlight", {"articlelist", R"#(\a)#", "red"});
+		try {
+			rxman.handle_action("highlight", {"articlelist", R"#(\a)#", "red"});
+		} catch (const ConfigHandlerException& e) {
+			const std::string expected(
+				R"#(`\a' is not a valid regular expression: trailing backslash (\))#");
+			REQUIRE(e.what() == expected);
+		}
 
 		std::string input = "\x07";
 		rxman.quote_and_highlight(input, "articlelist");
@@ -585,7 +725,13 @@ TEST_CASE("RegexManager uses POSIX extended regex syntax",
 	}
 
 	SECTION("No support for \\b as backspace control character") {
-		rxman.handle_action("highlight", {"articlelist", R"#(\b)#", "red"});
+		try {
+			rxman.handle_action("highlight", {"articlelist", R"#(\b)#", "red"});
+		} catch (const ConfigHandlerException& e) {
+			const std::string expected(
+				R"#(`\b' is not a valid regular expression: trailing backslash (\))#");
+			REQUIRE(e.what() == expected);
+		}
 
 		std::string input = "\x08";
 		rxman.quote_and_highlight(input, "articlelist");
