@@ -858,6 +858,27 @@ TEST_CASE("absolute_url()", "[utils]")
 			"bla2.html") == "http://test:test@foobar:33/bla2.html");
 }
 
+TEST_CASE("absolute_url() strips ASCII whitespace", "[utils]")
+{
+	// ASCII whitespace characters are: tab, line feed, form feed, carriage
+	// return, and space
+
+	REQUIRE(utils::absolute_url(" \t https://example.com/page1",
+			"page2") == "https://example.com/page2");
+	REQUIRE(utils::absolute_url("https://example.com/page3  \n ",
+			"page4") == "https://example.com/page4");
+	REQUIRE(utils::absolute_url("  \rhttps://example.com/page5  \f ",
+			"page6") == "https://example.com/page6");
+	REQUIRE(utils::absolute_url("https://example.com/base",
+			" \n replacement") == "https://example.com/replacement");
+	REQUIRE(utils::absolute_url("https://example.com/different",
+			"   another\t") == "https://example.com/another");
+	REQUIRE(utils::absolute_url("https://example.com/~joe/",
+			" \rhello\f") == "https://example.com/~joe/hello");
+	REQUIRE(utils::absolute_url( "\f\n\rhttps://example.com/misc/\t    ",
+			"   \t\feverything_at_once\n\r") == "https://example.com/misc/everything_at_once");
+}
+
 TEST_CASE("quote_for_stfl() adds a \'>\' after every \'<\'", "[utils]")
 {
 	REQUIRE(utils::quote_for_stfl("<<><><><") == "<><>><>><>><>");
@@ -906,10 +927,17 @@ TEST_CASE("strwidth_stfl()", "[utils]")
 	const auto input1 = utils::wstr2str(L"\uF91F");
 	REQUIRE(utils::strwidth_stfl(input1) == 2);
 	REQUIRE(utils::strwidth_stfl("\07") == 0);
+
+	REQUIRE(utils::strwidth_stfl("<a") == 0); // #415
+	REQUIRE(utils::strwidth_stfl("a") == 1);
+	REQUIRE(utils::strwidth_stfl("abc<tag>def") == 6);
+	REQUIRE(utils::strwidth_stfl("less-than: <>") ==  12);
+	REQUIRE(utils::strwidth_stfl("ＡＢＣＤＥＦ") == 12);
 }
 
 TEST_CASE("is_http_url()", "[utils]")
 {
+	REQUIRE(utils::is_http_url("http://example.com"));
 	REQUIRE(utils::is_http_url("http://foo.bar"));
 	REQUIRE(utils::is_http_url("https://foo.bar"));
 	REQUIRE(utils::is_http_url("http://"));
@@ -1726,14 +1754,7 @@ TEST_CASE("utf8_to_locale() converts text from UTF-8 to the encoding specified "
 	"by locale in LC_CTYPE class",
 	"[utils]")
 {
-	TestHelpers::EnvVar lc_ctype("LC_CTYPE");
-	lc_ctype.on_change([](nonstd::optional<std::string> new_charset) {
-		if (new_charset.has_value()) {
-			::setlocale(LC_CTYPE, new_charset.value().c_str());
-		} else {
-			::setlocale(LC_CTYPE, "");
-		}
-	});
+	TestHelpers::LcCtypeEnvVar lc_ctype;
 	const auto set_locale = [&lc_ctype](std::string new_locale) -> bool {
 		if (::setlocale(LC_CTYPE, new_locale.c_str()) == nullptr)
 		{
@@ -1791,14 +1812,7 @@ TEST_CASE("utf8_to_locale() converts text from UTF-8 to the encoding specified "
 TEST_CASE("utf8_to_locale() transliterates characters unsupported by the locale's encoding",
 	"[utils]")
 {
-	TestHelpers::EnvVar lc_ctype("LC_CTYPE");
-	lc_ctype.on_change([](nonstd::optional<std::string> new_charset) {
-		if (new_charset.has_value()) {
-			::setlocale(LC_CTYPE, new_charset.value().c_str());
-		} else {
-			::setlocale(LC_CTYPE, "");
-		}
-	});
+	TestHelpers::LcCtypeEnvVar lc_ctype;
 	const auto set_locale = [&lc_ctype](std::string new_locale) -> bool {
 		if (::setlocale(LC_CTYPE, new_locale.c_str()) == nullptr)
 		{
@@ -1846,14 +1860,7 @@ TEST_CASE("locale_to_utf8() converts text from the encoding specified by locale
 	"in LC_CTYPE class to UTF-8",
 	"[utils]")
 {
-	TestHelpers::EnvVar lc_ctype("LC_CTYPE");
-	lc_ctype.on_change([](nonstd::optional<std::string> new_charset) {
-		if (new_charset.has_value()) {
-			::setlocale(LC_CTYPE, new_charset.value().c_str());
-		} else {
-			::setlocale(LC_CTYPE, "");
-		}
-	});
+	TestHelpers::LcCtypeEnvVar lc_ctype;
 	const auto set_locale = [&lc_ctype](std::string new_locale) -> bool {
 		if (::setlocale(LC_CTYPE, new_locale.c_str()) == nullptr)
 		{
